aboutsummaryrefslogtreecommitdiff
path: root/source/enum_set.h
diff options
context:
space:
mode:
Diffstat (limited to 'source/enum_set.h')
-rw-r--r--source/enum_set.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/enum_set.h b/source/enum_set.h
index 28ee5fee..d4d31e33 100644
--- a/source/enum_set.h
+++ b/source/enum_set.h
@@ -200,8 +200,8 @@ class EnumSet {
std::unique_ptr<OverflowSetType> overflow_ = {};
};
-// A set of spv::Capability, optimized for small capability values.
-using CapabilitySet = EnumSet<spv::Capability>;
+// A set of SpvCapability, optimized for small capability values.
+using CapabilitySet = EnumSet<SpvCapability>;
} // namespace spvtools